@@ -314,6 +314,8 @@ parser.runTests(
     50% of 20
     20 * (1-20%)
     (100-20)% of 20
+    20% off
+    20% off of 20
     5 / 20%
     FV(20000, 3%, 30)
     PV(FV(20000, 3%, 30), 3%, 30)
