@@ -16,6 +16,10 @@ class TestCalculations:
             ("25%", 0.25),
             ("20 * 50%", 10),
             ("50% of 20", 10),
+            ("20% of 50", 10),
+            ("20% off", 0.8),
+            ("20% off of 50", 40),
+            ("50 less 20%", 40),
             ("20 * (1 - 20%)", 16),
             ("(100 - 20)% of 20", 16),
             ("5 / 20%", 25),
